@@ -920,25 +920,25 @@ getAbundanceClass = function(x) {
 #' 
 #' Assembles a list of output file names, which will be created during reporting.
 #' 
-#' You can combine @p report_name_has_folder and @p mzTab_filename to obtain filenames which are even more
+#' You can combine **report_name_has_folder** (and **mzTab_filename** for mzTab files) to obtain report filenames which are even more
 #' robust to moving around (since they contain infixes of the mzTab filename and the folder),
-#' e.g. @em report_HEK293-study_myProjects.html, where the input 
-#'      was mzTab_filename='HEK293-study.mzTab' and folder='c:/somePath/myProjects/'.
+#' e.g. `@em `report_HEK293-study_myProjects.html``, where the input 
+#'      was `mzTab_filename='HEK293-study.mzTab` and `folder='c:/somePath/myProjects/`.
 #' 
 #' @param folder Directory where the MaxQuant output (txt folder) or the mzTab file resides
 #' @param report_name_has_folder Boolean: Should the report files (html, pdf) contain the name
-#'        of the deepest(=last) subdirectory in 'txt_folder' which is not 'txt'?
+#'        of the deepest(=last) subdirectory in **txt_folder** which is not `txt`?
 #'        Useful for discerning different reports in a PDF viewer.
-#'        E.g. when flag is FALSE: 'report_v0.91.0.html'; and 'report_v0.91.0_bloodStudy.html' when flag is TRUE (and the
-#'        txt folder is '.../bloodStudy/txt/' or '...bloodStudy/', i.e. './txt/' will be skipped over)
+#'        E.g. when flag is FALSE: `report_v0.91.0.html`; and `report_v0.91.0_bloodStudy.html` when flag is TRUE (and the
+#'        txt folder is `.../bloodStudy/txt/` or `...bloodStudy/`)
 #' @param mzTab_filename If input is an mzTab, specify its name, so that the filenames can use its basename as infix
-#'        E.g. when mzTab_filename = 'HEK293-study.mzTab' then the output will be
-#'             report_HEK293-study.html.
+#'        E.g. when `mzTab_filename = 'HEK293-study.mzTab'` then the output will be
+#'             `report_HEK293-study.html`.
 #'        This allows to get reports on multiple mzTabs in the same folder without overwriting report results.
 #'        
 #' @return List of output file names (just names, no file is created) 
 #'         with list entries: 
-#'         yaml_file, heatmap_values_file, R_plots_file, filename_sorting, stats_file, log_file, report_file_prefix, report_file_PDF, report_file_HTML
+#'         **yaml_file**, **heatmap_values_file**, **R_plots_file**, **filename_sorting**, **stats_file**, **log_file**, **report_file_prefix**, **report_file_PDF**, **report_file_HTML**
 #' 
 #' @export
 #' 
@@ -966,12 +966,6 @@ getReportFilenames = function(folder, report_name_has_folder = TRUE, mzTab_filen
     report_file_simple = paste0(report_file_simple, "_", gsub("\\.mzTab$", "", basename(mzTab_filename), ignore.case = TRUE))
   }
   
-  yaml_file = paste0(report_file_simple, ".yaml")
-  heatmap_values_file = paste0(report_file_simple, "_heatmap.txt")
-  R_plots_file = paste0(report_file_simple, "_plots.Rdata")
-  filename_sorting = paste0(report_file_simple, "_filename_sort.txt")
-  stats_file = paste0(report_file_simple, "_stats.txt")
-  log_file = paste0(report_file_simple, ".log")
   
   ## include folder-name at the end
   if (report_name_has_folder)
@@ -979,12 +973,14 @@ getReportFilenames = function(folder, report_name_has_folder = TRUE, mzTab_filen
   else
     report_file_prefix = report_file_simple
   
-  fh = list(yaml_file = yaml_file,
-            heatmap_values_file = heatmap_values_file, 
-            R_plots_file = R_plots_file,
-            filename_sorting = filename_sorting,
-            stats_file = stats_file,
-            log_file = log_file,
+  
+  fh = list(yaml_file = paste0(report_file_prefix, ".yaml"),
+            heatmap_values_file = paste0(report_file_prefix, "_heatmap.txt"),
+            R_plots_file = paste0(report_file_prefix, "_plots.Rdata"),
+            filename_sorting = paste0(report_file_prefix, "_filename_sort.txt"),
+            stats_file = paste0(report_file_prefix, "_stats.txt"),
+            log_file = paste0(report_file_prefix, ".log"),
+            qc_file = paste0(report_file_prefix, ".mzQC"),
             report_file_prefix = report_file_prefix,
             report_file_PDF = paste0(report_file_prefix, ".pdf"),
             report_file_HTML = paste0(report_file_prefix, ".html")
