@@ -279,7 +279,8 @@ Each Raw file is now scored by the minimum LE of all its 4 channels.
       ## check if reporter.intensity.0... is present
       cols_reporter = grepv("^reporter.intensity.corrected.[0-9]", colnames(df_evd));
       cols_reporter.nc = grepv("^reporter.intensity.[0-9]", colnames(df_evd));
-      if(length(cols_reporter) <= 1 || length(cols_reporter.nc) <= 1) {warning("Two reporter.intensity and two reporter.intensity.corrected columns are needed for metric ReporterIntensity.")
+      if(length(cols_reporter) <= 1 || length(cols_reporter.nc) <= 1) {
+        message("Info: Two reporter.intensity and two reporter.intensity.corrected columns are needed for metric ReporterIntensity.")
         return()}
       ## check if correction was done at all
       if (all(df_evd[1:1000, cols_reporter] == df_evd[1:1000, cols_reporter.nc], na.rm = TRUE))
@@ -329,7 +330,7 @@ Each Raw file is now scored by the minimum LE of all its 4 channels.
           ylab("reporter intensity (log10)") +
           guides(alpha=guide_legend(title="Label Eff"), fill = guide_legend(reverse = TRUE)) + ## inverse label order, so that channel 0 is on top
           theme(axis.text.x = element_text(angle=45, vjust = 0.5), legend.position="right", plot.title = element_text(color=title_color)) +
-          addGGtitle("EVD: Reporter label intensities", title_subtext) + 
+          ggtitle("EVD: Reporter label intensities", title_subtext) + 
           #geom_hline(size = 1, alpha = 0.5, yintercept = ref_median, colour = "black") +
           scale_alpha(range = range(ylims$labEff_PC)) +
           scale_x_discrete_reverse(unique(data$fc.raw.file)) +
@@ -1120,7 +1121,7 @@ Heatmap score [EVD: Contaminants]: as fraction of summed intensity with 0 = samp
           byXflex(df_evd[, c("intensity", "pname", "fc.raw.file", "contaminant")], df_evd$fc.raw.file, 40, sort_indices = TRUE, 
                   plot_ContEVD, top5=cont.top5.names)
       }
-      
+
       ## QC measure for contamination
       qc_cont = plyr::ddply(df_evd[, c("intensity", "contaminant", "fc.raw.file")], "fc.raw.file", 
                       function(x) {
@@ -1259,7 +1260,7 @@ Heatmap score [EVD: Pep Missing]: Linear scale of the fraction of missing peptid
       lpl = byXflex(pep_set, pep_set$fc.raw.file, subset_size = 50, FUN = function(dx) {
         p = ggplot(dx) + 
           geom_bar(aes_string(x = "fc.raw.file", y = "idFraction"), stat = "identity") +
-          addGGtitle("[experimental] EVD: Non-Missing Peptides", "compared to all peptides seen in experiment") +
+          ggtitle("[experimental] EVD: Non-Missing Peptides", "compared to all peptides seen in experiment") +
           xlab("") +
           ylab("Fraction of total peptides [%]") +
           ylim(0, 100) +
@@ -1281,7 +1282,7 @@ Heatmap score [EVD: Pep Missing]: Linear scale of the fraction of missing peptid
       p = ggplot(tbl_smry, aes_string(x = "x", y = "FreqCum")) + 
         geom_line() +
         geom_point() +
-        addGGtitle("[experimental] EVD: Non-missing by set", "") +
+        ggtitle("[experimental] EVD: Non-missing by set") +
         xlab("Minimum # Raw files") +
         ylab("Fraction of total peptides [%]") +
         ylim(0, 100)
